@@ -10,13 +10,13 @@ def calculate_iou(bboxes1, bboxes2, dim: int = 2):
     coords_b1 = np.split(bboxes1, 2 * dim, axis=1)
     coords_b2 = np.split(bboxes2, 2 * dim, axis=1)
 
-    coords_tl, coords_br = dict(), dict()  # tl and br points
+    coords = np.zeros(shape=(2, dim, bboxes1.shape[0], bboxes2.shape[0]))
     val_inter, val_b1, val_b2 = 1.0, 1.0, 1.0
     for d in range(dim):
-        coords_tl[d] = np.maximum(coords_b1[d], np.transpose(coords_b2[d]))
-        coords_br[d] = np.minimum(coords_b1[d + dim], np.transpose(coords_b2[d + dim]))
+        coords[0, d] = np.maximum(coords_b1[d], np.transpose(coords_b2[d]))  # top-left
+        coords[1, d] = np.minimum(coords_b1[d + dim], np.transpose(coords_b2[d + dim]))  # bottom-right
 
-        val_inter *= np.maximum(coords_br[d] - coords_tl[d], 0)
+        val_inter *= np.maximum(coords[1, d] - coords[0, d], 0)
         val_b1 *= coords_b1[d + dim] - coords_b1[d]
         val_b2 *= coords_b2[d + dim] - coords_b2[d]
 
